@@ -3,7 +3,7 @@ from rest_framework import serializers
 from netbox.api.serializers import NetBoxModelSerializer
 from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
     NestedPartitionSerializer, NestedVolumeGroupSerializer
-from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, LogicalVolume, VolumeGroup
+from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, LogicalVolume, VolumeGroup, LinuxVolume
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
 
@@ -119,7 +119,7 @@ class LinuxVolumeSerializer(serializers.ModelSerializer):
     partition = NestedPartitionSerializer(required=False, allow_null=True)
 
     class Meta:
-        model = VolumeGroup
+        model = LinuxVolume
         fields = (
             "id",
             "partition",
