@@ -18,6 +18,7 @@ from utilities.forms import (
 
 from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume
 from virtualization.models import Cluster, ClusterType, VirtualMachine
+import logging
 
 
 class LVMSimpleForm(NetBoxModelForm):
@@ -95,25 +96,38 @@ class LVMSimpleForm(NetBoxModelForm):
         model = Drive
         exclude = (
                     "cluster_type",
-                    "cluster",
-                    "virtual_machine",
                     "lv_name",
                     "vg_name",
-                    "size",
                     "path",
                     "fs",
                     "description",
         )
+        fields = [
+            "cluster",
+            "virtual_machine",
+            "size",
+        ]
 
-    def clean(self):
-        super().clean()
-        drive = Drive(cluster=self.cluster, virtual_machine=self.virtual_machine, size=self.size)
-        drive.save()
-        partition = Partition(drive=drive, device=drive.device_name, size=self.size, type="Linux LVM")
+    def save(self, *args, **kwargs):
+        instance = super().save(*args, **kwargs)
+        logger = logging.getLogger('netbox.plugins.netbox_storage')
+
+        logger.warning(f'--------- Instance: {instance}')
+        logger.warning(f'--------- Instance: {instance.pk}')
+        partition = Partition(drive=instance, device=instance.device_name, size=instance.size, type="Linux LVM")
         partition.save()
+        logger.warning(f'{partition}')
         vg = VolumeGroup(vg_name=self.vg_name)
-        PhysicalVolume(partition=partition, pv_name=drive.device_name, vg=vg)
-        LogicalVolume(vg=vg, size=self.size, path=self.path, fs=self.fs)
+        vg.save()
+        logger.warning(f'{vg}')
+        physicalvolume = PhysicalVolume(partition=partition, pv_name=instance.device_name, vg=vg)
+        physicalvolume.save()
+        logger.warning(f'{physicalvolume}')
+        logicalvolume = LogicalVolume(vg=vg, size=self.size, path=self.path, fs=self.fs)
+        logger.warning(f'{logicalvolume}')
+        logicalvolume.save()
+
+        return instance
 
 
 class LVSimpleForm(NetBoxModelForm):
