@@ -96,8 +96,8 @@ class Migration(migrations.Migration):
                 ),
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
                 ("partition",
-                 models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="partition_physicalvolume",
-                                   to="netbox_storage.partition")),
+                 models.OneToOneField(on_delete=models.deletion.CASCADE, related_name="partition_physicalvolume",
+                                      to="netbox_storage.partition")),
                 ("vg",
                  models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="volumegroup_physicalvolume",
                                    to="netbox_storage.volumegroup", null=True)),
