@@ -9,9 +9,10 @@ from netbox.tables import (
 from netbox_storage.models import LogicalVolume
 
 
-class LogicalVolumeBaseTable(NetBoxTable):
-    """Base class for tables displaying LogicalVolume"""
+class LogicalVolumeTable(NetBoxTable):
+    """Table for displaying LogicalVolume objects."""
 
+    pk = ToggleColumn()
     fs = tables.Column(
         linkify=True,
         verbose_name="Filesystem"
@@ -25,12 +26,6 @@ class LogicalVolumeBaseTable(NetBoxTable):
         verbose_name="Logical Volume Name"
     )
 
-
-class LogicalVolumeTable(LogicalVolumeBaseTable):
-    """Table for displaying LogicalVolume objects."""
-
-    pk = ToggleColumn()
-
     class Meta(NetBoxTable.Meta):
         model = LogicalVolume
         fields = (
@@ -48,22 +43,3 @@ class LogicalVolumeTable(LogicalVolumeBaseTable):
             "fs",
             "description"
         )
-
-
-class RelatedLogicalVolumeTable(LogicalVolumeBaseTable):
-    actions = ActionsColumn(actions=())
-
-    class Meta(NetBoxTable.Meta):
-        model = LogicalVolume
-        fields = (
-            "pk",
-            "vg",
-            "lv_name",
-            "path",
-            "fs",
-            "description",
-        )
-        default_columns = (
-            "fs",
-            "description"
-        )
