@@ -8,9 +8,10 @@ from netbox.tables import (
 from netbox_storage.models import PhysicalVolume
 
 
-class PhysicalVolumeBaseTable(NetBoxTable):
-    """Base class for tables displaying PhysicalVolume"""
+class PhysicalVolumeTable(NetBoxTable):
+    """Table for displaying PhysicalVolume objects."""
 
+    pk = ToggleColumn()
     partition = tables.Column(
         linkify=True
     )
@@ -21,20 +22,17 @@ class PhysicalVolumeBaseTable(NetBoxTable):
         linkify=True
     )
 
-
-class PhysicalVolumeTable(PhysicalVolumeBaseTable):
-    """Table for displaying PhysicalVolume objects."""
-
-    pk = ToggleColumn()
-
     class Meta(NetBoxTable.Meta):
         model = PhysicalVolume
         fields = (
             "pk",
             "partition",
+            "pv_name",
             "description",
         )
         default_columns = (
+            "pk",
+            "partition",
             "pv_name",
             "description",
         )
