@@ -1,6 +1,6 @@
 from netbox.views import generic
 
-from netbox_storage.filters import VolumeGroupFilter, PhysicalVolumeFilter
+from netbox_storage.filters import VolumeGroupFilter, PhysicalVolumeFilter, LogicalVolumeFilter
 from netbox_storage.forms import (
     VolumeGroupImportForm,
     VolumeGroupFilterForm,
@@ -8,8 +8,8 @@ from netbox_storage.forms import (
     VolumeGroupBulkEditForm
 )
 
-from netbox_storage.models import VolumeGroup, PhysicalVolume
-from netbox_storage.tables import VolumeGroupTable, PhysicalVolumeTable
+from netbox_storage.models import VolumeGroup, PhysicalVolume, LogicalVolume
+from netbox_storage.tables import VolumeGroupTable, PhysicalVolumeTable, LogicalVolumeTable
 from utilities.views import register_model_view, ViewTab
 
 
@@ -65,15 +65,36 @@ class VolumeGroupPhysicalVolumeListView(generic.ObjectChildrenView):
     table = PhysicalVolumeTable
     filterset = PhysicalVolumeFilter
     template_name = "netbox_storage/volumegroup/physicalvolume.html"
-    hide_if_empty = False
+    hide_if_empty = True
 
     tab = ViewTab(
         label="Physical Volumes",
         badge=lambda obj: obj.physical_volume_count(),
-        hide_if_empty=False,
+        hide_if_empty=True,
     )
 
     def get_children(self, request, parent):
         return PhysicalVolume.objects.filter(
             vg=parent
         )
+
+
+@register_model_view(VolumeGroup, "logicalvolumes")
+class VolumeGroupLogicalVolumeListView(generic.ObjectChildrenView):
+    queryset = VolumeGroup.objects.all()
+    child_model = LogicalVolume
+    table = LogicalVolumeTable
+    filterset = LogicalVolumeFilter
+    template_name = "netbox_storage/volumegroup/logicalvolume.html"
+    hide_if_empty = True
+
+    tab = ViewTab(
+        label="Logical Volumes",
+        badge=lambda obj: obj.logical_volume_count(),
+        hide_if_empty=True,
+    )
+
+    def get_children(self, request, parent):
+        return LogicalVolume.objects.filter(
+            vg=parent
+        )
